# Installation

All examples work with Python 3.7+ on Windows, Linux, MacOS.
You will need to have Python's pip installed (https://pip.pypa.io/en/stable/).

If you are about to install pip for the first time, make sure that your `~/.local/bin` directory is part of the `$PATH`.
For a POSIX based system you either have to re-login or execute `source ~/.profile`.

Then, create a virtual environment:

```
$ python3 -m venv ./venv
```

And activate it, on POSIX systems:

```
$ source ./venv/bin/activate
```

On windows systems:

```
C:\> venv\Scripts\activate.bat
OR
PS C:\> venv\Scripts\Activate.ps1
```

Upgrade pip, install the requirements and (re-)source the environment variables:

```
(venv) $ pip3 install -U pip
(venv) $ pip3 install -r requirements.txt
(venv) $ source ./venv/bin/activate
```

Next you need to generate an API secrets file.  You can skip this step if you've done it before.

```
(venv) $ python3 generate_api_secrets.py
Please enter the required information:
Realm (from: <realm>.analysis.threatray.com): testium
Username: bob
Password: ***
Created secrets file: threatray_api_secrets.json
Consider moving it to ~/.threatray/threatray_api_secrets.json
```

The threatray_api_secrets.json file contains your realm and secret token configuration. If the API is
initialized, it will try to read it from `~/.threatray/threatray_api_secrets.json` first, if that fails it will
try to load it from `./threatray_api_secrets.json`. Alternatively, the path to the file can be given with
`API(api_secret_file_path=/tmp/my_secret.json)`.

```
api = API()
# Do a request to the API, while setting the authorization header.
res = requests.get(f'{api.get_api_url()}/v1/submissions', headers=api.get_authorization_header())
```

Make sure to activate the venv every time you use the scripts or demos in the future.

# Scripts

The scripts directory contains files to analyze samples, fetch reports, issue threat queries, etc.
Refer to the `scripts/README.md` file for more information.
