import getpass
import json
import sys
import os

from threatray.api import API
from threatray.api.auth.oauth2 import Credential

secrets_file = 'threatray_api_secrets.json'
if os.path.exists(secrets_file):
    print(f'Secrets file {secrets_file} already exists, overwrite? (y/n)')
    if 'y' not in input().lower():
        print('Exiting.')
        sys.exit(0)

    os.remove(secrets_file)

print(f'Please enter the required information:')
realm = input(f'Realm (from: <realm>.analysis.threatray.com): ')
user = input('Username: ')
password = getpass.getpass()
if not password:
    print('No password given, exiting.')
    sys.exit(1)

api = API(realm)
secret_token = api.get_secret_token(Credential(username=user, password=password))

with open(secrets_file, 'w') as f:
    json.dump({'realm': realm, 'secret_token': secret_token}, f)

print(f'Created secrets file: {secrets_file}')
print(f'Consider moving it to ~/.threatray/{secrets_file}.')
