import argparse
import sys
import requests

from threatray.api import API

api = API()


def download_file(file_hash):
    dest_path = f'{file_hash}.zip'
    with requests.get(f'{api.get_api_url()}/v1/files/{file_hash}/data?zipped',
                      headers=api.get_authorization_header()) as r:
        if r.status_code != 200:
            print(f'File does not exist, status code: {r.status_code}')
        else:
            with open(dest_path, 'wb') as f:
                f.write(r.content)
            print(f'Downloaded file to: {dest_path}')


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Download a file by hash.')
    parser.add_argument('--hash', required=True, type=str, help='Hash (MD5, SHA1, SHA256) of the file to download.')

    if len(sys.argv) < 2:
        parser.print_help()
        sys.exit(0)

    args = parser.parse_args()

    download_file(args.hash)
