import argparse
import json
import sys

import requests
from threatray.api import API

api = API()


def import_public_analysis(analysis_id, label, priority):
    data = {
        'label': label,
        'priority': priority,
    }

    resp = requests.post(f'{api.get_api_url()}/v1/analyses/{analysis_id}/import',
                         json=data,
                         headers=api.get_authorization_header())
    if resp.status_code != 201:
        try:
            error = resp.json().get("description", "unknown error")
        except json.JSONDecodeError as _:
            error = 'unknown error'
        print(f'Failed to import analysis: {error}')
        return

    data = resp.json()
    if data['submissions']:
        print(f'Importing analysis.')
    else:
        print('No submissions were created for the given analysis id.')
        return


def main():
    parser = argparse.ArgumentParser(description='Import a public analysis into a private environment.')
    parser.add_argument('--analysis-id', required=True, type=str, help='Public analysis id')
    parser.add_argument('--label', required=False, type=str, default='', help='Label of the analysis.')
    parser.add_argument('--priority', required=False, default=5, type=int, choices=range(0, 10),
                        help='Processing priority (0=low, 9=high).')

    if len(sys.argv) < 2:
        parser.print_help()
        sys.exit(0)

    args = parser.parse_args()
    import_public_analysis(args.analysis_id, args.label, args.priority)


if __name__ == "__main__":
    main()
