import argparse
from datetime import datetime
import requests
from texttable import Texttable
from threatray.api import API

api = API()


def get_submissions():
    resp = requests.get(f'{api.get_api_url()}/v1/submissions', headers=api.get_authorization_header())
    if resp.status_code != 200:
        print(f'Failed to get the submissions: [{resp.status_code}] {resp.text}')
        return []

    return resp.json()


def display_submissions():
    table = Texttable(max_width=400)
    table.set_deco(Texttable.HEADER | Texttable.BORDER)
    table.set_cols_dtype(['t', 't', 't', 't', 't', 't', 't', 't'])
    table.header(['User', 'Created at', 'Analysis ID', 'File name', 'SHA256', 'Verdict', 'Threats', 'Status'])

    submissions = get_submissions()
    for submission in submissions['submissions'][:10]:
        if 'sample' in submission and 'analysis' in submission:
            table.add_row([
                submission['username'],
                datetime.fromtimestamp(submission['created_at']),
                submission['analysis']['id'],
                submission['sample']['file_name'],
                submission['sample']['hash_sha256'],
                submission['analysis']['verdict'],
                [t['label'] for t in submission['analysis']['threats']],
                submission['status']
            ])

    print(table.draw())


if __name__ == '__main__':
    parser = argparse.ArgumentParser()

    args = parser.parse_args()

    display_submissions()
