import argparse
import sys

import requests
from threatray.api import API

api = API()


def upload_minidump_archive(file_path, label):
    data = {
        'label': label,
    }

    files = {'file': open(file_path, 'rb')}

    resp = requests.post(f'{api.get_api_url()}/v1/submissions/minidump',
                         data=data,
                         files=files,
                         headers=api.get_authorization_header())
    if resp.status_code != 201:
        try:
            msg = resp.json()["error"]["message"]
        except:
            msg = ''

        print(f'Failed to submit archive for analysis: {msg if msg else resp.text}')
        return

    data = resp.json()
    if data['submissions']:
        print(f'Submitted file for analysis, created {len(data["submissions"])} submission(s).')
    else:
        print('No submissions were created for the submitted archive.')
        return


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Submit a minidump (archive) for analysis.')
    parser.add_argument('--file-path', required=True, type=str, help='Path to the minidump file or archive.')
    parser.add_argument('--label', required=False, type=str, default='', help='Label of the analysis.')

    if len(sys.argv) < 2:
        parser.print_help()
        sys.exit(0)

    args = parser.parse_args()

    upload_minidump_archive(args.file_path, args.label)
